<?php

namespace App\Jobs;

use App\Models\CalendarPrice;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Carbon;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Log;

class CalendarPriceSavingJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    protected array $searchCriteriaFlight;
    protected Collection $bestPriceCombinedOffer;

    /**
     * Create a new job instance.
     */
    public function __construct(array $searchCriteriaFlight, Collection $bestPriceCombinedOffer)
    {
        $this->searchCriteriaFlight = $searchCriteriaFlight;
        $this->bestPriceCombinedOffer = $bestPriceCombinedOffer;
    }

    /**
     * Execute the job.
     */
    public function handle(): void
    {
        $prices = [];
        $prices[] = $this->extractAdultPrice(
            $this->bestPriceCombinedOffer->where("@type", "Outbound")->first());

        $inboundOffer = $this->bestPriceCombinedOffer->where("@type", "Inbound")->first();
        $prices[] = $inboundOffer ? $this->extractAdultPrice($inboundOffer) : null;

        Log::info('Outbound Price: ' . $prices[0]);
        Log::info('Inbound Price: ' . $prices[1]);


        foreach ($this->searchCriteriaFlight as $index => $searchCriteria) {
            CalendarPrice::create([
                'search_date' => Carbon::today(),
                'from' => $searchCriteria['From']['value'],
                'to' => $searchCriteria['To']['value'],
                'departure_date' => $searchCriteria['departureDate'],
                'price' => $prices[$index] ?? null,
            ]);
        }
    }

    protected function extractAdultPrice(array $product)
    {
        return Collection::wrap($product['price']['PriceBreakdown'])
            ->where("requestedPassengerType", "ADT")
            ->first()['Amount']['Total'];
    }
}
