<?php

namespace App\Jobs;

use App\Models\TpCombinedOffer;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Log;

class TravelportCombinedOffersSavingJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    protected Collection $combinedOffers;
    protected string $catalogProductOfferingId;

    /**
     * Create a new job instance.
     */
    public function __construct(string $catalogProductOfferingId, Collection $combinedOffers)
    {
        $this->catalogProductOfferingId = $catalogProductOfferingId;
        $this->combinedOffers = $combinedOffers;
    }

    /**
     * Execute the job.
     */
    public function handle(): void
    {
        Log::info('Combined offers save job started.');
        try {
            $offers = $this->combinedOffers->map(function (Collection $content, $key) {
                return [
                    'catalogIdentifier' => $this->catalogProductOfferingId,
                    'combinableCode' => $key,
                    'offers' => json_encode($content->toArray()),
                    'bestCombinablePrice' => floatval($content->first()['bestCombinablePrice']['TotalPrice']),
                ];
            });

            TpCombinedOffer::insert($offers->toArray());

            Log::info('Combined offers save job ended.');
        } catch (\Exception $exception) {
            Log::error($exception->getMessage());
        }
    }
}
