<?php

namespace App\domain\travelport;

use App\Models\CommitResponse;
use Exception;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Facades\Log;

class CommitReservation extends Workbench
{
    protected string $reservationId;

    public function execute(string $reservationId)
    {
        $this->reservationId = $reservationId;

        $apiUrl = $this->buildApiUrl();

        try {
            $response = $this->client->post($apiUrl, [
                'headers' => $this->getHeaders()
            ]);

            $reservationResponse = json_decode($response->getBody(), true);

            if (isset($reservationResponse['ReservationResponse']['Reservation']) &&
                !empty($reservationResponse['ReservationResponse']['Reservation'])) {
                $this->saveResponse($reservationResponse);
            }

            return $reservationResponse;
        } catch (Exception $e) {
            Log::error("CommitReservation: Error: " . $e->getMessage());
            return null;
        } catch (GuzzleException $e) {
            Log::error("CommitReservation: Guzzle Reqeust Error: " . $e->getMessage());
            return null;
        }
    }

    protected function buildApiUrl(): string
    {
        return "https://{$this->baseURL}/{$this->apiVersion}/air/book/reservation/reservations/{$this->reservationId}";
    }

    protected function createPayload(): array
    {
        return [
            "ReservationQueryCommitReservation" => [
                "@type" => "ReservationQueryCommitReservation",
                "scheduleChangeAcceptedInd" => true
            ]
        ];
    }

    protected function saveResponse($response): void
    {
        $commitResponse = new CommitResponse();
        $commitResponse->reservation_id = $this->reservationId;
        $commitResponse->locator_id = $response['ReservationResponse']['Reservation']['Receipt'][0]['Confirmation']['Locator']['value'];
//        $commitResponse->locator_id = "";
        $commitResponse->response = json_encode($response);
        $commitResponse->save();
    }
}
